/* --------------------------------------------------------------------------
 *
 * Copyright (C) 2007 Leif Erik Larsen, Kjerringvik, Norway.
 *
 * This file is part of the Open Source Edition of Larsen Commander, as
 * available from http://home.online.no/~leifel/lcmd/.  This code is free 
 * software; you can redistribute it and/or modify it under the terms of 
 * the GNU General Public License version 3 only, as published by the 
 * Free Software Foundation.  
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 3 at http://www.gnu.org/licenses/gpl-3.0.txt for more details 
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * ------------------------------------------------------------------------ */

#ifndef __LCMD_COPYFILEITEM
#define __LCMD_COPYFILEITEM

#include "glib/primitives/GString.h"

/**
 * Objects of this class represents a single file of which to be either
 * copied or moved by {@link LCmdCopy#CopyOrMoveFiles}. It is also used 
 * indirectly by {@link LCmdDlgCalcDirSize}.
 *
 * @author  Leif Erik Larsen
 * @since   2000.04.18
 * @see     LCmdFilePanel#makeArrayOfCopyFileItems
 */
class LCmdCopyFileItem : public GObject
{
   private:

      GString srcPath;
      GString dstPath;

   public:

      explicit LCmdCopyFileItem ( const GString& srcPath,
                                  const GString* dstPath = null );

      virtual ~LCmdCopyFileItem ();

   public:

      const GString& getSourcePath () const;
      const GString& getDestPath () const;
      void setDestPath ( const GString& dstPath );
};

#endif // #ifndef __LCMD_COPYFILEITEM
